"use client";
import { ColumnDefinition, CustomDataTable } from "@/components/common/table/cutom-data-table";
import BlurFade from "@/components/ui/blur-fade";
import { Button } from "@/components/ui/button";
import { useNotifications } from "@/servers/data/use-notification";
import { format } from "date-fns";
import { ChevronLeft, ChevronRight, Loader2 } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import { useState } from "react";


type Notification = {
	id: string;
	notifiable_type: string;
	notifiable_id: string;
	notification_type: string;
	notification_description: string;
	date: Date;
	description_ar?: string;
	description_en?: string;
	created_at?: string;
};

export function NotificationsTable() {
	const t = useTranslations();
	const locale = useLocale();

	const [currentPage, setCurrentPage] = useState(1);
	const itemsPerPage = 10;
	const { notifications, isLoading, isError } = useNotifications(currentPage, itemsPerPage);

	// Calculate pagination
	const totalItems = notifications?.length || 0;
	const totalPages = Math.ceil(totalItems / itemsPerPage);
	const startIndex = (currentPage - 1) * itemsPerPage;
	const endIndex = startIndex + itemsPerPage;
	const currentNotifications = notifications?.slice(startIndex, endIndex) || [];

	const handlePreviousPage = () => {
		setCurrentPage((prev) => Math.max(prev - 1, 1));
	};

	const handleNextPage = () => {
		setCurrentPage((prev) => Math.min(prev + 1, totalPages));
	};

	const columns: ColumnDefinition<Notification>[] = [
		{
			header: t("NotificationDescription"),
			align: "center",
			key: "notification_description",
			render: (value: any, row: any) => {
				return (
					<p className="text-custom-fourth">
						{locale === "ar" ? row?.description_ar : row?.description_en}
					</p>
				);
			},
		},
		{
			header: t("Date"),
			align: "center",
			key: "date",
			render: (value: any, row: any) => (
				<>
					<p dir="ltr" className="mb-1 text-custom-fourth">
						{row?.created_at ? format(new Date(row.created_at), "dd MMM, yyyy") : ""}
					</p>
				</>
			),
		},
	];

	return (
		<BlurFade direction="down" delay={0.25} inView>
			{
				isLoading ?
					<Loader2 className="mx-auto w-4 h-4 animate-spin" />
					:
					isError ?
						<p className="flex justify-center items-center h-64 text-custom-fourth">{t("Something went wrong")}</p>
						:
						notifications?.length > 0 ? <div className="space-y-4">
							<CustomDataTable columns={columns} data={currentNotifications} locale={locale} />
							{totalPages > 1 && (
								<div className="flex items-center justify-between px-2">
									<div className="text-sm text-custom-fifth">
										{t("Showing")} {startIndex + 1}-{Math.min(endIndex, totalItems)} {t("of")} {totalItems}
									</div>
									<div className="flex items-center space-x-2">
										<Button
											variant="outline"
											size="sm"
											onClick={handlePreviousPage}
											disabled={currentPage === 1}
										>
											<ChevronLeft className="h-4 w-4" />
										</Button>
										<span className="text-sm text-custom-fifth">
											{t("Page")} {currentPage} {t("of")} {totalPages}
										</span>
										<Button
											variant="outline"
											size="sm"
											onClick={handleNextPage}
											disabled={currentPage === totalPages}
										>
											<ChevronRight className="h-4 w-4" />
										</Button>
									</div>
								</div>
							)}
						</div> :
							<div className="flex justify-center items-center h-64">
								{t("No notifications found")}
							</div>
			}
		</BlurFade>
	);
}
